@@ -5,9 +5,9 @@ from aiohttp.client_reqrep import ClientResponse
 import aiohttp
 import os
 import werkzeug
+from . import defaults
 from icecream import ic
-
-SERVER_BASE_URL_DEFAULT = 'https://preview.learning-loop.ai'
+import logging
 
 
 class AccessToken():
@@ -18,6 +18,8 @@ class AccessToken():
     def is_still_valid(self) -> bool:
         return (self.local_expire_date - timedelta(hours=1)) > datetime.now()
 
+    def is_invalid(self) -> bool:
+        return not self.is_still_valid
 
 async def token_from_response(response: ClientResponse) -> AccessToken:
     content = await response.json()
@@ -28,19 +30,15 @@ async def token_from_response(response: ClientResponse) -> AccessToken:
     return AccessToken(content['access_token'], local_expire_time)
 
 
-class LoopHttp():
+class Loop():
     def __init__(self) -> None:
-        self.base_url: str = os.environ.get('SERVER_BASE_URL', SERVER_BASE_URL_DEFAULT)
+        self.base_url: str = 'http://' + os.environ.get('HOST', defaults.HOST)
         self.username: str = os.environ.get('USERNAME', None)
         self.password: str = os.environ.get('PASSWORD', None)
         self.access_token = None
-        self.token_future = None
 
     async def download_token(self):
-        if self.token_future:
-            return self.token_future
-        self.token_future = asyncio.Future()
-
+      
         credentials = {
             'username': self.username,
             'password': self.password,
@@ -48,22 +46,22 @@ class LoopHttp():
 
         async with aiohttp.ClientSession() as session:
             async with session.post(f'{self.base_url}/api/token', data=credentials) as response:
+                logging.debug(f'received token from {self.base_url}')
                 assert response.status == 200
 
-                token = await token_from_response(response)
-                self.token_future.set_result(token)
-                self.token_future = None
-                return token
-
+                return await token_from_response(response)
+    
     async def get_headers(self) -> dict:
         headers = {}
-        if self.username is not None:
-            if self.access_token is None or not self.access_token.is_still_valid():
-                self.access_token = await self.download_token()
+        if self.username is None:
+            return headers
 
-            if self.access_token is not None:
-                headers['Authorization'] = f'Bearer {self.access_token.token}'
+        if self.access_token is None or self.access_token.is_invalid():
+            self.access_token = await self.download_token()
+
+        headers['Authorization'] = f'Bearer {self.access_token.token}'
         return headers
+        
 
     @asynccontextmanager
     async def get(self, path):
@@ -87,4 +85,4 @@ class LoopHttp():
                 yield response
 
 
-instance = LoopHttp()
+loop = Loop()
